@@ -26,7 +26,7 @@
 
 k9Progress::k9Progress(TQWidget* parent, const char* name,const TQStringList &args)
         : Progress(parent,name,0) {
-    m_process=new k9Process(TQT_TQOBJECT(this),0);
+    m_process=new k9Process(this,0);
     m_wimage=new k9DrawImage(image,0);
     TQGridLayout *l=new TQGridLayout(image,1,1);
     l->addWidget(m_wimage,0,0);
